@@ -6,7 +6,7 @@ package OAuthomatic;
 
 
 use Moose;
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 use namespace::sweep;
 # FIXME: switch to Moo
 use MooseX::AttributeShortcuts;
@@ -24,8 +24,8 @@ use OAuthomatic::SecretStorage;
 use OAuthomatic::OAuthInteraction;
 use OAuthomatic::UserInteraction;
 use OAuthomatic::Internal::UsageGuard;
-use OAuthomatic::Internal::Util;
-use OAuthomatic::ServerDef;
+use OAuthomatic::Internal::Util qw/serialize_json parse_http_msg_json/;
+use OAuthomatic::ServerDef qw/oauthomatic_predefined_for_name/;
 
 ###########################################################################
 # Construction support, fixed attributes
@@ -101,7 +101,7 @@ has 'user_interaction' => (is => 'lazy', does => 'OAuthomatic::UserInteraction')
 has '_micro_web' => (is => 'lazy');
 
 sub _build_secret_storage {
-    my $self = shift;
+    my ($self) = @_;
     require OAuthomatic::SecretStorage::Keyring;
     print "[OAuthomatic] Constructing default secret_storage\n" if $self->debug;
     return OAuthomatic::SecretStorage::Keyring->new(
@@ -109,7 +109,7 @@ sub _build_secret_storage {
 }
 
 sub _build_user_interaction {
-    my $self = shift;
+    my ($self) = @_;
     require OAuthomatic::UserInteraction::ViaMicroWeb;
     print "[OAuthomatic] Constructing default user_interaction\n" if $self->debug;
     return OAuthomatic::UserInteraction::ViaMicroWeb->new(
@@ -117,7 +117,7 @@ sub _build_user_interaction {
 }
 
 sub _build_oauth_interaction {
-    my $self = shift;
+    my ($self) = @_;
     require OAuthomatic::OAuthInteraction::ViaMicroWeb;
     print "[OAuthomatic] Constructing default oauth_interaction\n" if $self->debug;
     return OAuthomatic::OAuthInteraction::ViaMicroWeb->new(
@@ -125,7 +125,7 @@ sub _build_oauth_interaction {
 }
 
 sub _build__micro_web {
-    my $self = shift;
+    my ($self) = @_;
     require OAuthomatic::Internal::MicroWeb;
     print "[OAuthomatic] Constructing MicroWeb object\n" if $self->debug;
     return OAuthomatic::Internal::MicroWeb->new(
@@ -187,6 +187,7 @@ sub _update_client_cred {
 
     # Changed client means access is no longer valid
     $self->_update_token_cred(undef);
+    return;
 }
 
 # Updates token_cred both in-memory and in storage. $force param ignores identity check
@@ -204,19 +205,22 @@ sub _update_token_cred {
     }
 
     $self->token_cred($new_cred);
+    return;
 }
 
 
 sub erase_client_cred {
-    my $self = shift;
+    my ($self) = @_;
 
     $self->_update_client_cred(undef);
+    return;
 }
 
 
 sub erase_token_cred {
-    my $self = shift;
+    my ($self) = @_;
     $self->_update_token_cred(undef);
+    return;
 }
 
 ###########################################################################
@@ -237,7 +241,7 @@ has '_oauth_interaction_guard' => (
 
 # Ensures app tokens are known
 sub _ensure_client_cred_known {
-    my $self = shift;
+    my ($self) = @_;
 
     return if $self->_caller->client_cred;
 
@@ -253,11 +257,12 @@ sub _ensure_client_cred_known {
     # We save them straight away, in memory to use, in storage to keep them in case of crash
     # or Ctrl-C (later we will clear them if they turn out wrong).
     $self->_update_client_cred($client_cred);
+    return;
 }
 
 # Ensures access tokens are known
 sub _ensure_token_cred_known {
-    my $self = shift;
+    my ($self) = @_;
     return if $self->_caller->token_cred;
 
     # To proceed we must have client credentials
@@ -319,6 +324,8 @@ sub _ensure_token_cred_known {
     # Close supporting objects if they were started
     $self->_user_interaction_guard->finish;
     $self->_oauth_interaction_guard->finish;
+
+    return;
 }
 
 
@@ -337,9 +344,8 @@ sub ensure_authorized {
 
 
 sub execute_request {
-    my $self = shift;
+    my ($self, @args) = @_;
     $self->ensure_authorized;
-    my @args = @_;
     my $reply;
 
     # Loop to retry on some failures
@@ -376,11 +382,13 @@ sub execute_request {
 }
 
 
+## no critic (RequireArgUnpacking)
 sub build_request {
     my $self = shift;
     $self->ensure_authorized;
     return $self->_caller->build_oauth_request(@_);
 }
+## use critic
 
 
 sub get {
@@ -406,7 +414,7 @@ sub get_json {
     my $r = $self->execute_request(
         method => "GET", url => $url, url_args => $url_args);
 
-    return parse_httpmsg_json($r, 'force');  # FIXME: or error on content-type mismatch?
+    return parse_http_msg_json($r, 'force');  # FIXME: or error on content-type mismatch?
 }
 
 
@@ -460,7 +468,7 @@ sub post_json {
 
     my $r = $self->execute_request(@args);
 
-    return parse_httpmsg_json($r);
+    return parse_http_msg_json($r);
 }
 
 
@@ -513,7 +521,7 @@ sub put_json {
 
     my $r = $self->execute_request(@args);
 
-    return parse_httpmsg_json($r);
+    return parse_http_msg_json($r);
 }
 
 
@@ -541,7 +549,7 @@ OAuthomatic - automate setup of access to OAuth-secured resources. Intended espe
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -559,16 +567,16 @@ Construct the object:
              site_name => "SomeSite.com",
              site_client_creation_page => "https://some.site.com/settings/oauth_apps",
              site_client_creation_desc => "SomeSite applications page",
-             site_client_creation_help => <<"HELP",
-Click Create App button and fill the form. Use AppToken as client key
-and AppSecret as client secret. For application created in the past,
-click application name and visit Tokens tab.
-HELP
+             site_client_creation_help =>
+                 "Click Create App button and fill the form.\n"
+                 . "Use AppToken as client key and AppSecret as client secret.\n"),
     );
 
 and profit:
 
-    my $info = $oauthomatic->get_json($PROTECTED_URL, par1=>'v1', par2=>'v2');
+    my $info = $oauthomatic->get_json(
+        'https://some.site.com/api/get_issues',
+        { type => 'bug', page_len => 10, release => '7.3' });
 
 On first run user (maybe just you) will be led through OAuth
 initialization sequence, but the script need not care.
