@@ -5,6 +5,7 @@ package OAuthomatic::Caller;
 use Moose;
 
 use version;
+use feature 'state';
 use Const::Fast;
 use LWP::UserAgent;
 use URI;
@@ -13,7 +14,7 @@ use HTTP::Request;
 use HTTP::Headers;
 use Net::OAuth;
 use OAuthomatic::Error;
-use OAuthomatic::Internal::Util;
+use OAuthomatic::Internal::Util qw/fill_httpmsg_text fill_httpmsg_form parse_http_msg_form/;
 use namespace::sweep;
 
 const my $OAUTH_REALM => "OAuthomatic";
@@ -155,6 +156,7 @@ sub create_token_cred {
 ###########################################################################
 
 
+## no critic (RequireArgUnpacking)
 sub build_oauth_request {
     my $self = shift;
 
@@ -169,8 +171,10 @@ sub build_oauth_request {
         token => $self->token_cred,
         @_);
 }
+## use critic
 
 
+## no critic (RequireArgUnpacking)
 sub execute_oauth_request {
     my $self = shift;
 
@@ -185,6 +189,7 @@ sub execute_oauth_request {
         token => $self->token_cred,
         @_);
 }
+## use critic
 
 
 sub _build_oauth_request_ext {
@@ -344,6 +349,7 @@ sub _build_oauth_request_ext {
 }
 
 
+## no critic (RequireArgUnpacking)
 sub _execute_oauth_request_ext {
     my $self = shift;
     my $request = $self->_build_oauth_request_ext(@_);
@@ -361,6 +367,7 @@ sub _execute_oauth_request_ext {
 
     return $response;
 }
+## use critic
 
 ###########################################################################
 # Helpers
@@ -371,7 +378,7 @@ sub _net_oauth_version_constant {
     my $ver = $self->protocol_version;
     return Net::OAuth::PROTOCOL_VERSION_1_0A() if $ver eq '1.0a';
     return Net::OAuth::PROTOCOL_VERSION_1_0() if $ver eq '1.0';
-    OAuthomatic::Error::Generic->throw(
+    return OAuthomatic::Error::Generic->throw(
         ident => "Invalid parameter",
         extra => "Invalid protocol version: $ver");
 }
@@ -382,34 +389,25 @@ sub _using_legacy_oauth10 {
     return 0;
 }
 
-# Pair (timestamp-rounded-to-second, nonce) should be unique.  Usual
-# random should do in practical cases, but there is tiny risk of
-# collisions.  Marsenne-Twister, with its uniform distribution,
-# reduces this risk even further.
-BEGIN {
-    eval {
-        require Math::Random::MT;
-        my $rnd_gen = Math::Random::MT->new();
-        *_nonce = sub {
-            return $rnd_gen->rand(2**32);
-        };
-        1;
-    } or do {
-        srand();
-        *_nonce = sub {
-            return int( rand( 2**32 ) );
-        };
-    };
-    # Random setup
-    srand();
-};
+# How many requests per second can reasonably happen, as 2 power
+const my $_NONCE_UNIQ_BITS => 6;
+const my $_NONCE_UNIQ_MAX => (2 ** $_NONCE_UNIQ_BITS);
+const my $_NONCE_RANDOM_MAX => (2 ** (31 - $_NONCE_UNIQ_BITS));
+
+sub _nonce {
+    # This ensures no collisions in succeessive requests (after all we need no collision within 1s)
+    state $counter = 0;
+    $counter = ($counter + 1) % $_NONCE_UNIQ_MAX;
+    # And this adds general randomness
+    return $counter + $_NONCE_UNIQ_MAX * int(rand($_NONCE_RANDOM_MAX));
+}
 
 # Checks response: throws exception on error, parses and returns param hash
 # Second param, if present, is a list of required parameters
 sub _parse_form_reply {
     my ($http_response, $required_params) = @_;
 
-    my $params = parse_httpmsg_form($http_response, 1);
+    my $params = parse_http_msg_form($http_response, 1);
 
     if($required_params) {
         foreach my $par_name (@$required_params) {
@@ -439,7 +437,7 @@ OAuthomatic::Caller - actually make OAuth-signed calls
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -533,7 +531,7 @@ JSON, XML or even binary data). Example:
 
 Value of body can be either binary string (which will be posted as-is), or
 perl unicode string (which will be encoded according to the content type, what by
-default means utf-8). 
+default means utf-8).
 
 Such content is not covered by OAuth signature, so less secure (at
 least if it is posted over non-SSL connection).
