@@ -13,18 +13,21 @@ sub prepare {
     return if $self->_active;
     $self->obj->prepare_to_work;
     $self->_active(1);
+    return;
 }
 
 sub finish {
     my $self = shift;
     return unless $self->_active;
     $self->obj->cleanup_after_work;
-    $self->_active(0)
+    $self->_active(0);
+    return;
 }
 
 sub DEMOLISH {
     my $self = shift;
     $self->finish;
+    return;
 }
 
 1;
@@ -41,7 +44,7 @@ OAuthomatic::Internal::UsageGuard - support for RAII for some roles
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
