@@ -15,15 +15,19 @@ has 'micro_web' => (is=>'ro', isa=>'OAuthomatic::Internal::MicroWeb', required=>
 sub prepare_to_work {
     my $self = shift;
     $self->micro_web->start_using;
+    return;
 }
 
 sub cleanup_after_work {
     my $self = shift;
     $self->micro_web->finish_using;
+    return;
 }
 
 with 'OAuthomatic::OAuthInteraction';
 
+1;
+
 __END__
 
 =pod
@@ -36,7 +40,7 @@ OAuthomatic::OAuthInteraction::ViaMicroWeb - Handling oauth callback via embedde
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
