@@ -9,14 +9,14 @@ use warnings;
 {
     package OAuthomaticForgetTokens;
     use Moose;
-    our $VERSION = '0.01'; # VERSION
+    our $VERSION = '0.02'; # VERSION
     with 'MooseX::Getopt';
     has 'password_group' => (is=>'ro', isa=>'Str', required=>1);
     has 'site_name' => (is=>'ro', isa=>'Str', required=>1);
     has 'app' => (is=>'ro', isa=>'Bool', default=>'OAuthomatic');
 
     sub run {
-        my $self = shift;
+        my ($self) = @_;
         die "Not yet implemented\n";
     }
 }
@@ -36,7 +36,7 @@ oauthomatic_forget_tokens - remove remembered tokens for given site
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
